[gnome-shell/gnome-40] switcherPopup: Rename _onItemEnter() to _onItemMotion()



commit 3ce0d9c1b4c5bb67e34469eff17e588b0e1395a4
Author: Jonas Dreßler <verdre v0yd nl>
Date:   Wed Jan 12 11:36:41 2022 +0100

    switcherPopup: Rename _onItemEnter() to _onItemMotion()
    
    Since commit e94de67b, this is called by a motion-event handler instead
    of enter-event, so let's adjust the function name.
    
    (cherry picked from commit 87101cf165d6a818f819f4c146491dcb985e5b9a)
    
    Part-of: <https://gitlab.gnome.org/GNOME/gnome-shell/-/merge_requests/2181>

 js/ui/altTab.js        | 4 ++--
 js/ui/switcherPopup.js | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/js/ui/switcherPopup.js b/js/ui/switcherPopup.js
index b1e2730068..ccc8b0fb0e 100644
--- a/js/ui/switcherPopup.js
+++ b/js/ui/switcherPopup.js
@@ -428,7 +428,7 @@ var SwitcherList = GObject.registerClass({
         this._list.add_actor(bbox);
 
         bbox.connect('clicked', () => this._onItemClicked(bbox));
-        bbox.connect('motion-event', () => this._onItemEnter(bbox));
+        bbox.connect('motion-event', () => this._onItemMotion(bbox));
 
         bbox.label_actor = label;
 
@@ -455,7 +455,7 @@ var SwitcherList = GObject.registerClass({
         this._itemActivated(this._items.indexOf(item));
     }
 
-    _onItemEnter(item) {
+    _onItemMotion(item) {
         // Avoid reentrancy
         if (item !== this._items[this._highlighted])
             this._itemEntered(this._items.indexOf(item));


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/js/ui/altTab.js b/js/ui/altTab.js
index 6af9380edc..26c92de0c7 100644
--- a/js/ui/altTab.js
+++ b/js/ui/altTab.js
@@ -794,9 +794,9 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
         }
     }
 
     // We override SwitcherList's _onItemEnter method to delay
     // activation when the thumbnail list is open
-    _onItemEnter(item) {
+    _onItemMotion(item) {
         const index = this._items.indexOf(item);
 
         if (this._mouseTimeOutId != 0)
@@ -794,9 +794,9 @@ class AppSwitcher extends SwitcherPopup.SwitcherList {
     }
 
-    // We override SwitcherList's _onItemEnter method to delay
+    // We override SwitcherList's _onItemMotion method to delay
     // activation when the thumbnail list is open